@@ -574,7 +574,7 @@ int AppletInterface::screen() const
 
 QRect AppletInterface::screenGeometry() const
 {
-    if (!applet() || !applet()->containment()) {
+    if (!applet() || !applet()->containment() || !applet()->containment()->corona()) {
         return QRect();
     }
     return applet()->containment()->corona()->screenGeometry(applet()->containment()->screen());
@@ -688,7 +688,10 @@ QVariantList AppletInterface::availableScreenRegion() const
         reg = applet()->containment()->corona()->availableScreenRegion(screenId);
     }
 
-    foreach (QRect rect, reg.rects()) {
+    auto it = reg.begin();
+    const auto itEnd = reg.end();
+    for (; it != itEnd; ++it) {
+        QRect rect = *it;
         //make it relative
         QRect geometry = applet()->containment()->corona()->screenGeometry(screenId);
         rect.moveTo(rect.topLeft() - geometry.topLeft());
